<?php
/**
 * vs_featured_functions.php
 * @author  Sean Barton <info@pro-webs.net>
 * @copyright Copyright 2008 PRO-Webs.net
 * @license http://www.gnu.org/licenses/gpl.txt GNU General Public License V2.0
 */
vs_db_check();

function vs_get_meta_value($meta_key) {
	global $db;

	$sql = 'SELECT meta_value
			FROM ' . DB_PREFIX . 'vs_meta
			WHERE meta_key = "' . $meta_key . '"
			LIMIT 1';
	$result = $db->Execute($sql);

	return $result->fields['meta_value'];
}

function vs_process_for_display($content) {

	if ($content) {
		$content = str_replace('_', ' ', $content);
		$content = ucwords($content);
	} else {
		$content = '-';
	}

	return $content;
}

function vs_get_sidebar_boxes($num_to_show) {
	global $db;

	$content = '';
	$boxes = vs_get_boxes('sidebar', $num_to_show);

	if ($boxes->RecordCount()) {
		while (!$boxes->EOF) {
			$content .= vs_render_featured($boxes);

			$boxes->MoveNext();
		}
	}

	return $content;
}

function vs_get_featured($result) {
	$content = '';

	$image = zen_image(DIR_WS_IMAGES . $result->fields['products_image'], $result->fields['products_name'], SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT);
	$path_rev = zen_get_generated_category_path_rev($result->fields["master_categories_id"]);
	$info_path = zen_get_info_page($result->fields["products_id"]);
	$href = zen_href_link($info_path, 'cPath=' . $path_rev . '&products_id=' . $result->fields["products_id"]);

	$content .= '<div class="sideBoxContent centeredContent">';
	$content .=  '<a href="' . $href . '">' . $image;

	if (vs_get_meta_value('sidebar_show_titles')) {
		$content .= '<div>' . $result->fields['products_name'] . '</div>';
	}

	if (vs_get_meta_value('sidebar_show_prices')) {
		$price = zen_get_products_display_price($result->fields['products_id']);
		$content .= '<div>' . $price . '</div>';
	}

	$content .= '</div>';

	return $content;
}

function vs_render_featured($boxes) {
	global $db;

	$value = $boxes->fields['key_id'];
	$excludes = $boxes->fields['excludes'];
	$key_type = $boxes->fields['key_type'];
	$sql = false;
	$content = false;

	switch (trim($key_type)) {
		case 'random':
			$sql = vs_get_featured_sql(false, false, $excludes);
			break;
		case 'random_from_category':
			$sql = vs_get_featured_sql($value, false, $excludes);
			break;
		case 'product_id':
			$sql = vs_get_featured_sql(false, $value, $excludes);
			break;
	}

	if ($sql) {
		$box_inner = $db->Execute($sql);

		if ($box_inner->RecordCount()) {
			$content = vs_get_featured($box_inner);
		}
	}

	return $content;
}

function vs_get_featured_sql($category_id=false, $product_id=false, $excludes=false) {
	$sql = "SELECT p.products_id, p.products_image, pd.products_name, p.master_categories_id
			FROM
				" . TABLE_PRODUCTS . " p
				LEFT JOIN " . TABLE_FEATURED . " f ON (p.products_id = f.products_id)
				LEFT JOIN " . TABLE_PRODUCTS_DESCRIPTION . " pd on (p.products_id = pd.products_id)
			WHERE
				p.products_id = f.products_id
				AND p.products_id = pd.products_id
				AND p.products_status = 1
				AND pd.language_id = '" . (int)$_SESSION['languages_id'] . "'";

	if ($category_id) {
		$sql .= ' AND p.master_categories_id = ' . $category_id;
	}

	if ($excludes) {
		$sql .= ' AND p.products_id NOT IN (' . $excludes . ')';
	}

	if ($product_id) {
		$sql .= ' AND p.products_id = ' . $product_id;
	} else {
		$sql .= ' AND f.status = 1';
	}

	$sql .= " ORDER BY RAND() LIMIT 1";

	return $sql;
}

function vs_get_homepage_boxes($num_to_show) {
	global $db;

	$content = '';
	$boxes = vs_get_boxes('homepage', $num_to_show);

	if ($boxes->RecordCount()) {
		while (!$boxes->EOF) {
			$content .= '<div class="vs_featured_homepage_container_div" style="width: 33%; float: left; overflow: auto;">';
			$content .= vs_render_featured($boxes);
			$content .= '</div>';

			$boxes->MoveNext();
		}
		$content .= '<div style="clear: both;">&nbsp;</div>';
	}

	return $content;
}

function vs_get_boxes($type, $num_to_show=1) {
	global $db;

	$sql = 'SELECT key_type, type, key_id, excludes
			FROM ' . DB_PREFIX . 'vs_display
			WHERE type ="' . $type . '"
			ORDER BY RAND()
			LIMIT ' . $num_to_show;
	return $db->Execute($sql);
}

function vs_db_check() {
	global $db;

	$sql = 'SHOW TABLES LIKE \'' . DB_PREFIX . 'vs_display\'';
	$result = $db->Execute($sql);

	if (!$result->RecordCount()) {
		$sql = 'CREATE TABLE `' . DB_PREFIX . 'vs_display` (
		  `id` int(11) NOT NULL auto_increment,
		  `key_type` varchar(255) default NULL COMMENT \'random or random_from_category or product_id\',
		  `key_id` int(11) default NULL,
		  `excludes` varchar(255) default NULL,
		  `type` varchar(255) default NULL COMMENT \'sidebar or homepage\',
		  PRIMARY KEY  (`id`)
		);';
		$db->Execute($sql);

		$db->Execute('INSERT INTO `' . DB_PREFIX . 'vs_display` VALUES (\'1\', \'random\', null, null, \'sidebar\');');
		$db->Execute('INSERT INTO `' . DB_PREFIX . 'vs_display` VALUES (\'2\', \'random\', null, null, \'sidebar\');');
		$db->Execute('INSERT INTO `' . DB_PREFIX . 'vs_display` VALUES (\'3\', \'random\', null, null, \'sidebar\');');
	}

	$sql = 'SHOW TABLES LIKE \'' . DB_PREFIX . 'vs_meta\'';
	$result = $db->Execute($sql);

	if (!$result->RecordCount()) {
		$sql = 'CREATE TABLE `' . DB_PREFIX . 'vs_meta` (
		`id` int(11) NOT NULL auto_increment,
		`meta_key` varchar(255) NOT NULL,
		`meta_value` text,
		PRIMARY KEY  (`id`)
		);';
		$db->Execute($sql);

		$db->Execute('INSERT INTO `' . DB_PREFIX . 'vs_meta` VALUES (\'1\', \'sidebar_boxes\', \'3\');');
		$db->Execute('INSERT INTO `' . DB_PREFIX . 'vs_meta` VALUES (\'2\', \'sidebar_title\', \'VS Featured Products\');');
		$db->Execute('INSERT INTO `' . DB_PREFIX . 'vs_meta` VALUES (\'4\', \'sidebar_show_prices\', \'1\');');
		$db->Execute('INSERT INTO `' . DB_PREFIX . 'vs_meta` VALUES (\'5\', \'sidebar_show_titles\', \'1\');');
	}
}


?>